@@ -16,6 +16,7 @@ from stressor.plugins.base import (
     register_plugins,
 )
 from stressor.util import (
+    NO_DEFAULT,
     PathStack,
     StressorError,
     assert_always,
@@ -129,6 +130,10 @@ class ConfigManager:
         #     self.read(path)
         return
 
+    def get(self, key_path, default=NO_DEFAULT):
+        res = get_dict_attr(self.config_all, key_path, default)
+        return res
+
     def resolve_path(self, path, must_exist=True, check_root=True, default_ext=None):
         """Return an absolute path, assuming relative to the original config file."""
         # TODO: check for invalid access (security risk!)
@@ -323,6 +328,7 @@ class ConfigManager:
             stack = self.stack
             # Register sequence names
             for seq_name in value.get("sequences", {}).keys():
+                # Create an initial statistics dict for sequence_stats[SEQ_NAME]:
                 stats.register_sequence(seq_name)
 
         if parent_key == "activity":
@@ -420,6 +426,13 @@ class ConfigManager:
             except yaml.parser.ParserError as e:
                 raise ConfigurationError("Could not parse YAML: {}".format(e)) from None
 
+        if not isinstance(res, dict) or not res.get("file_version", "").startswith(
+            "stressor#"
+        ):
+            raise ConfigurationError(
+                "Not a `stressor` file (missing 'stressor#VERSION' tag)."
+            )
+
         self._compile(res)
 
         self.file_version = self.validate_config(res)
