@@ -7,13 +7,12 @@ import itertools
 import sys
 import threading
 import time
-import webbrowser
 from collections import defaultdict
 from datetime import datetime
 
 from stressor.config_manager import ConfigManager
 from stressor.log import log
-from stressor.monitor.server import Monitor
+from stressor.monitor.server import MonitorServer
 from stressor.plugins.base import register_plugins
 from stressor.session_manager import SessionManager, User
 from stressor.statistic_manager import StatisticManager
@@ -208,8 +207,10 @@ class RunManager:
         return "\n".join(lines)
 
     def get_status_info(self):
-        stats_info = self.stats.get_monitor_info()
         rc = self.run_config
+
+        stats_info = self.stats.get_monitor_info(rc)
+
         res = {
             "name": self.config_manager.name,
             "scenarioDetails": rc.get("details", "n.a."),
@@ -287,7 +288,7 @@ class RunManager:
             t.setDaemon(True)  # Required to make Ctrl-C work
             thread_list.append(t)
 
-        logger.info("Starting session workers...")
+        logger.info("Starting {} session workers...".format(len(thread_list)))
         self.set_stage("running")
         self.stats.report_start(None, None, None)
 
@@ -303,7 +304,11 @@ class RunManager:
                 time.sleep(delay)
             t.start()
 
-        logger.info("All session workers running, now waiting for them to terminate...")
+        logger.info(
+            "All {} sessions running, waiting for them to terminate...".format(
+                len(thread_list)
+            )
+        )
         for t in thread_list:
             t.join()
 
@@ -355,9 +360,10 @@ class RunManager:
 
         monitor = None
         if self.options.get("monitor"):
-            monitor = Monitor(self)
+            monitor = MonitorServer(self)
             monitor.start()
-            webbrowser.open_new_tab("http://127.0.0.1:8081/")
+            time.sleep(0.5)
+            monitor.open_browser()
 
         self.start_dt = datetime.now()
         self.end_dt = None
