@@ -208,7 +208,7 @@ def run():
     del args.quiet
 
     # print("verbose", args.verbose)
-    init_logging(args.verbose)
+    init_logging(args.verbose, args.log_file)
 
     if not args.no_color and sys.stdout.isatty():
         log.enable_color(True)
