@@ -6,13 +6,22 @@
 import logging
 import os
 import random
+import re
 import sys
 import types
 import warnings
 from datetime import datetime
 
+from dateutil.parser import isoparse
+from urllib.parse import urlparse, urljoin
+
+
 logger = logging.getLogger("stressor")
 
+#: Check if a a string may be used as YAML dictionary key without using quotes.
+#: NOTE: YAML evaluates `0_` as "0" and `0_1_` as "1", so we don't accept leading numbers
+RE_YAML_KEYWORD = re.compile(r"^[a-zA-Z_]+\w*$")
+
 
 class StressorError(RuntimeError):
     """Base class for all exception that we deliberatly throw."""
@@ -97,7 +106,19 @@ class PathStack:
         return self.delimiter + self.delimiter.join(stack)
 
 
-def init_logging(verbose=3):
+def timetag(seconds=True, ms=False):
+    """Return a time stamp string that can be used as (part of a) filename (also sorts well)."""
+    now = datetime.now()
+    if ms or seconds:
+        s = now.strftime("%Y%m%d_%H%M%S")
+        if ms:
+            s = "{}_{}".format(s, now.microsecond)
+    else:
+        s = now.strftime("%Y%m%d_%H%M")
+    return s
+
+
+def init_logging(verbose=3, path=None):
     """CLI calls this."""
     if verbose < 1:
         level = logging.CRITICAL
@@ -109,6 +130,7 @@ def init_logging(verbose=3):
         level = logging.INFO
     else:
         level = logging.DEBUG
+
     logging.basicConfig(
         level=level,
         # format="%(asctime)s.%(msecs)03d <%(thread)d> %(levelname)-7s %(message)s",
@@ -119,6 +141,27 @@ def init_logging(verbose=3):
         datefmt="%H:%M:%S",
     )
 
+    if path:
+        if os.path.isdir(path):
+            fname = "stressor_{}.log".format(timetag())
+            path = os.path.join(path, fname)
+        logger.info("Writing log to '{}'".format(path))
+        if os.path.isfile(path):
+            logger.warning("Removing log file '{}'".format(path))
+            os.remove(path)
+        hdlr = logging.FileHandler(path)
+        formatter = logging.Formatter(
+            "%(asctime)s.%(msecs)-3d - %(levelname)s: %(message)s", "%H:%M:%S"
+        )
+        hdlr.setFormatter(formatter)
+        logger.addHandler(hdlr)
+        # logger.setLevel(logging.DEBUG)
+        logger.info("Start log ({})".format(datetime.now()))
+        logger.info("Running {}".format(" ".join(sys.argv)))
+
+        # redirect `logger` to our special log file as well:
+        logger.addHandler(hdlr)
+
     # Silence requests `InsecureRequestWarning` messages
     if verbose < 3:
         warnings.filterwarnings("ignore", message="Unverified HTTPS request")
@@ -415,6 +458,35 @@ def parse_args_from_str(arg_str, arg_defs):  # , context=None):
     return res
 
 
+def is_yaml_keyword(s):
+    """Return true if `s` is a JSON compatible key."""
+    return bool(s and RE_YAML_KEYWORD.match(s))
+
+
+# def is_abs_url(url):
+#     """Return true if url is already absolute."""
+#     return "://" in url or url.startswith("/")
+
+
+def is_relative_url(url):
+    """Return true if url is relative to the server."""
+    return "://" not in url  # or url.startswith("/")
+
+
+def resolve_url(root, url):
+    """Convert relative URL to absolute, using `root` as default."""
+    return urljoin(root, url)
+
+
+def base_url(url):
+    parsed_uri = urlparse(url)
+    if parsed_uri.netloc:
+        res = "{uri.scheme}://{uri.netloc}{uri.path}".format(uri=parsed_uri)
+    else:
+        res = "{uri.path}".format(uri=parsed_uri)
+    return res
+
+
 def shorten_string(long_string, max_chars, min_tail_chars=0, place_holder="[...]"):
     """Return string, shortened to max_chars characters.
 
@@ -478,7 +550,9 @@ def datetime_to_iso(dt=None, microseconds=False):
 
 def iso_to_datetime(iso):
     """Convert as ISO formatted datetime string to datetime."""
-    dt = datetime.strptime(iso, "%Y-%m-%dT%H:%M:%S.%fZ")
+    # dt = datetime.strptime(iso, "%Y-%m-%dT%H:%M:%S.%fZ")
+    dt = isoparse(iso)
+
     return dt
 
 
